PyLumerical
===========
|pyansys| |python| |pypi| |codecov| |GH-CI| |MIT| |ruff|

.. |pyansys| image:: https://img.shields.io/badge/Py-Ansys-ffc107.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAABDklEQVQ4jWNgoDfg5mD8vE7q/3bpVyskbW0sMRUwofHD7Dh5OBkZGBgW7/3W2tZpa2tLQEOyOzeEsfumlK2tbVpaGj4N6jIs1lpsDAwMJ278sveMY2BgCA0NFRISwqkhyQ1q/Nyd3zg4OBgYGNjZ2ePi4rB5loGBhZnhxTLJ/9ulv26Q4uVk1NXV/f///////69du4Zdg78lx//t0v+3S88rFISInD59GqIH2esIJ8G9O2/XVwhjzpw5EAam1xkkBJn/bJX+v1365hxxuCAfH9+3b9/+////48cPuNehNsS7cDEzMTAwMMzb+Q2u4dOnT2vWrMHu9ZtzxP9vl/69RVpCkBlZ3N7enoDXBwEAAA+YYitOilMVAAAAAElFTkSuQmCC
   :target: https://docs.pyansys.com/
   :alt: PyAnsys

.. |python| image:: https://img.shields.io/pypi/pyversions/ansys-lumerical-core?logo=pypi
   :target: https://pypi.org/project/ansys-lumerical-core/
   :alt: Python

.. |pypi| image:: https://img.shields.io/pypi/v/ansys-lumerical-core.svg?logo=python&logoColor=white&label=PyPI
   :target: https://pypi.org/project/ansys-lumerical-core
   :alt: PyPI

.. |codecov| image:: https://codecov.io/github/ansys/pylumerical/graph/badge.svg?token=34FKDS6ZKJ
   :target: https://codecov.io/github/ansys/pylumerical
   :alt: Codecov

.. |GH-CI| image:: https://github.com/ansys/pylumerical/actions/workflows/ci_cd_pr.yml/badge.svg
   :target: https://github.com/ansys/pylumerical/actions/workflows/ci_cd_pr.yml

.. |MIT| image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
   :alt: MIT

.. |ruff| image:: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json
   :target: https://github.com/astral-sh/ruff
   :alt: Ruff


A Python wrapper for Ansys Lumerical products.

Installing PyLumerical as a user
--------------------------------

You must have an Ansys Lumerical GUI license to use PyLumerical.

You can install PyLumerical using pip.

First, ensure that you have the latest pip version:

.. code:: bash

    python -m pip install -U pip

Then, install using:

.. code:: bash

    python -m pip install ansys-lumerical-core

For more information, see the `installation and getting started section <https://lumerical.docs.pyansys.com/version/stable/getting_started/index.html>`_ in the documentation.

Contributing to PyLumerical
---------------------------

For guidelines on contribution and how to install PyLumerical as a developer, see the `contributing section <https://lumerical.docs.pyansys.com/version/stable/contributing.html>`_ section in the documentation.

Getting started
----------------

Please see the `installation and getting started section <https://lumerical.docs.pyansys.com/version/stable/getting_started/index.html>`_ in the documentation for more information.
